-- Bankler's modified Labels.lua
-- This configuration overwrites all levels of labels (except "off") to the same mini pixel setting.

-- Tweak the following two values to whatever works best for your hardware:
local y_offset = -4
local font_size = 12

-- Label parameters
-- Copyright (C) 2018, Eagle Dynamics.

AirOn			 		= true
GroundOn 		 		= false
NavyOn		 	 		= false
WeaponOn 		 		= false
labels_format_version 	= 2 -- labels format vesrion
---------------------------------
-- Label text format symbols
-- %N - name of object
-- %D - distance to object
-- %P - pilot name
-- %n - new line 
-- %% - symbol '%'
-- %x, where x is not NDPn% - symbol 'x'
-- %C - extended info for vehicle's and ship's weapon systems
------------------------------------------
-- Example
-- labelFormat[5000] = {"Name: %N%nDistance: %D%n Pilot: %P","LeftBottom",0,0}
-- up to 5km label is:
--       Name: Su-33
--       Distance: 30km
--       Pilot: Pilot1

-- alignment options 
--"RightBottom"
--"LeftTop"
--"RightTop"
--"LeftCenter"
--"RightCenter"
--"CenterBottom"
--"CenterTop"
--"CenterCenter"
--"LeftBottom"

local aircraft_symbol_near  =  "˄" --U+02C4
local aircraft_symbol_far   =  "˄" --U+02C4

local ground_symbol_near    = "ˉ"  --U+02C9
local ground_symbol_far     = "ˉ"  --U+02C9

local navy_symbol_near      = "˜"  --U+02DC
local navy_symbol_far       = "˜"  --U+02DC

local weapon_symbol_near    = "ˈ"  --U+02C8
local weapon_symbol_far     = "ˈ"  --U+02C8

local function dot_symbol(blending,opacity)
    return {"˙","CenterBottom", blending or 1.0, opacity or 0.1}
end

local DISTANCE             = "%D"
local NAME 				   = "%n  %N"
local DISTANCE_NAME        = DISTANCE..NAME
local DISTANCE_NAME_PLAYER = DISTANCE_NAME.."%n  %P"
local ABB_NAME 			   = "%N"

-- Text shadow color in {red, green, blue, alpha} format, volume from 0 up to 255
-- alpha will by multiplied by opacity value for corresponding distance
local text_shadow_color = {128, 128, 128, 255}
local text_blur_color 	= {0, 0, 255, 255}

local EMPTY = {"", "LeftBottom", 1, 1, 0, 0}

-- Colors in {red, green, blue} format, volume from 0 up to 255
--The color blending decides the blend of unidentified/identified labels. In our case we fade from light gray to dark gray (regardless of faction).
local nearLight = 60
local distantLight = 150
local maxAlpha = 255
local minAlpha = 255

-- Colors in {red, green, blue} format, volume from 0 up to 255
ColorAliesSide = {nearLight, nearLight, nearLight, maxAlpha}
ColorEnemiesSide = {nearLight, nearLight, nearLight, maxAlpha}
ColorUnknown = {distantLight, distantLight, distantLight, minAlpha} -- will be blend at distance with coalition color

local function NEUTRAL_DOT_BANKLER()
	local alignment = "CenterCenter"
	local x = 0
	local y = y_offset
	
	local res = {
		--[distance]	= {format , alignment,color_blending_k,opacity,shift_pixels_x, shift_in_pixels_y}
		[500]	= {"", alignment, 0.0, 0.0, x, y}, --0.27nm
		[600]	= {"", alignment, 0.0, 0.1, x, y},
		[700]	= {"", alignment, 0.05, 0.05, x, y},
		[800]	= {"", alignment, 0.10, 0.10, x, y},
		[900]	= {"", alignment, 0.15, 0.15, x, y},
		[1000]	= {"", alignment, 0.20, 0.20, x, y}, --0.54nm
		[1100]	= {"˙", alignment, 0.25, 0.25, x, y},
		[1200]	= {"˙", alignment, 0.30, 0.30, x, y},
		[1300]	= {"˙", alignment, 0.35, 0.35, x, y},
		[1400]	= {"˙", alignment, 0.40, 0.40, x, y},
		[1500]	= {"˙", alignment, 0.45, 0.45, x, y}, --0.81nm
		[1600]	= {"˙", alignment, 0.50, 0.50, x, y},
		[1700]	= {"˙", alignment, 0.55, 0.55, x, y},
		[1800]	= {"˙", alignment, 0.60, 0.60, x, y},
		[1900]	= {"˙", alignment, 0.65, 0.65, x, y},
		[2000]	= {"˙", alignment, 0.70, 0.70, x, y}, --1.07nm
		[3000]	= {"˙", alignment, 0.75, 0.75, x, y},
		[4000]	= {"˙", alignment, 0.80, 0.80, x, y},
		[5000]	= {"˙", alignment, 0.85, 0.85, x, y}, --2.70nm
		[6000]	= {"˙", alignment, 0.90, 0.90, x, y},
		[7000]	= {"˙", alignment, 0.85, 0.85, x, y},
		[8000]	= {"˙", alignment, 0.80, 0.80, x, y},
		[9000]	= {"˙", alignment, 0.75, 0.75, x, y},
		[10000]	= {"˙", alignment, 0.70, 0.70, x, y}, --5.40nm
		[11000]	= {"˙", alignment, 0.675, 0.675, x, y},
		[12000]	= {"˙", alignment, 0.650, 0.650, x, y},
		[13000]	= {"˙", alignment, 0.625, 0.625, x, y},
		[14000]	= {"˙", alignment, 0.600, 0.600, x, y},
		[15000]	= {"˙", alignment, 0.575, 0.575, x, y}, --8.10nm
		[16000]	= {"˙", alignment, 0.550, 0.550, x, y},
		[17000]	= {"˙", alignment, 0.525, 0.525, x, y},
		[18000]	= {"˙", alignment, 0.500, 0.500, x, y},
		[19000]	= {"˙", alignment, 0.475, 0.475, x, y},
		[20000]	= {"˙", alignment, 0.450, 0.450, x, y}, --10.80nm
		[21000]	= {"˙", alignment, 0.425, 0.425, x, y},
		[22000]	= {"˙", alignment, 0.400, 0.400, x, y},
		[23000]	= {"˙", alignment, 0.375, 0.375, x, y},
		[24000]	= {"˙", alignment, 0.350, 0.350, x, y}, 
		[25000]	= {"˙", alignment, 0.325, 0.325, x, y}, --13.50nm
		[26000]	= {"˙", alignment, 0.300, 0.300, x, y},
		[27000]	= {"˙", alignment, 0.275, 0.275, x, y},
		[28000]	= {"˙", alignment, 0.250, 0.250, x, y},
		[29000]	= {"˙", alignment, 0.225, 0.225, x, y},
		[30000]	= {"˙", alignment, 0.200, 0.200, x, y}, --16.20nm
		[31000]	= {"˙", alignment, 0.175, 0.175, x, y},
		[32000]	= {"˙", alignment, 0.150, 0.150, x, y},
		[33000]	= {"˙", alignment, 0.125, 0.125, x, y},
		[34000]	= {"˙", alignment, 0.100, 0.100, x, y},
		[35000]	= {"˙", alignment, 0.075, 0.075, x, y}, --18.90nm
		[36000]	= {"˙", alignment, 0.050, 0.050, x, y},
		[37000]	= {"˙", alignment, 0.025, 0.025, x, y}, --20.00m,
		
		[80000]	= {"", alignment, 0.0000, 0.0000, x, y}, --43.20nm
	}

	return res
end

local baseNeutralDotColor = {75,75,75} 

LEVEL_NEUTRAL_DOT = {
	AirFormat 	 = NEUTRAL_DOT_BANKLER(),
	--------------------------------------------------------
	ColorAliesSide   		= ColorAliesSide,   		
	ColorEnemiesSide 		= ColorEnemiesSide, 		
	ColorUnknown     		= ColorUnknown,     		

	ShadowColorNeutralSide 	= ShadowColorNeutralSide, 	
	ShadowColorAliesSide	= ShadowColorAliesSide,	
	ShadowColorEnemiesSide 	= ShadowColorEnemiesSide, 	
	ShadowColorUnknown 		= ShadowColorUnknown, 		

	BlurColorNeutralSide 	= BlurColorNeutralSide, 	
	BlurColorAliesSide		= BlurColorAliesSide,		
	BlurColorEnemiesSide	= BlurColorEnemiesSide,	
	BlurColorUnknown		= BlurColorUnknown,	 
	--------------------------------------------------
	font_properties 		= {"DejaVuLGCSans.ttf", font_size},
}

LEVEL_DOT = LEVEL_NEUTRAL_DOT
LEVEL_ABBREVIATED = LEVEL_NEUTRAL_DOT
LEVEL_FULL = LEVEL_NEUTRAL_DOT